@@ -146,7 +146,7 @@ char * gom_options_help[] =
 	"[" GOM_DEVICE_NOT_OPENED_TEXT "] Set mixer special device file to <argument>. "
 	"If the new mixer is valid, the current mixer --if any-- will be closed and "
 	"the new mixer opened. Current channel, current channel volume, the channel "
-	"lock setting and the snapshot will be resetted to defaults.",
+	"lock setting and the snapshot will be reset to defaults.",
 	/* channel  */
 	"[first available channel] Set current mixer channel to <argument>. "
 	"The channel may be given as number or as name.",
@@ -177,7 +177,7 @@ char * gom_options_help[] =
 	/* loudness  */
 	"Set current volume channel on current channel to <argument>. "
 	"If the argument is being given with a leading \"+\" or \"-\", the given value will be added or "
-	"substracted, respectively, from the current value. The allowed range is from zero up to a soundcard driver "
+	"subtracted, respectively, from the current value. The allowed range is from zero up to a soundcard driver "
 	"dependent maximum.",
 	/* record  */
 	"Set recording for current channel on or off.",
