@@ -115,7 +115,7 @@ void gom_iface_t_refresh();
  */
 void gom_iface_t_cntrprintw(int line, char * str)
 {
-	mvprintw(line, (COLS - strlen(str)) / 2, str);
+	mvprintw(line, (COLS - strlen(str)) / 2, "%s", str);
 }
 
 void gom_iface_t_filline(int line, char ch)
@@ -188,7 +188,7 @@ char * gom_iface_t_get_option_arg(char * prompt)
 
 	default:
 		gom_iface_t_filline(GOM_IFACE_T_INFO_LINE, ' ');
-		mvprintw(GOM_IFACE_T_INFO_LINE, 0, prompt);
+		mvprintw(GOM_IFACE_T_INFO_LINE, 0, "%s", prompt);
 
 		/* stop auto-refresh */
 		gom_gomii_refival_set(GOM_INFO_VERBOSE+1, gom_gomii_refival(), NULL);
